//______________________________________________________________________________

//            Hlavikov soubor knihovny Tpci1054u.dll verze 1.00

//                Copyright (c) 1998-2014 TEDIA spol. s r.o.
//______________________________________________________________________________

unit Tpci1054u;

interface
uses Windows, Classes, SysUtils, Wintypes;

//______________________________________________________________ NVRATOV A CHYBOV KDY

//   0      V podku
//   1      Chybn komunikan rychlost
//   2      (rezervovno)
//   3      Chyba pi vysln zprvy
//   4      Timeout - nepila dn odpov
//   5      Timeout - nepila sprvn odpov
//   6      Odpov peruena
//   7      Chyba parity odpovdi
//   8      Chybn hlavika odpovdi
//   9      Chyba CRC odpovdi
//  10      Nelze vytvoit datovou strukturu knihovny
//  11      Chyba inicializanch parametr
//  12      Neplatn handle zazen
//  13      Chyba pstupu k zazen
//  14      Chyba knihovny Tedia_OX952
//  15      Nenalezena dn karta PCI-1054U
//  16      Nenalezena poadovan karta PCI-1054U

//______________________________________________________________ DATOV TYPY

type
  TPar   = array[0..15] of DWord;   // pole DWord (16 prvku)
  PTPar  = ^TPar;                   // ukazatel na pole DWord
  TBuff  = array[0..1023] of DWord; // pole DWord (1024 prvku)
  PTBuff = ^TBuff;                  // ukazatel na pole DWord


//______________________________________________________________ EXPORTOVAN FCE

// Vechny funkce vrac hodnotu 0 (DWord) v ppad spnho proveden.
// Nenulov hodnota signalizuje chybu, pro jej identifikaci lze pout
// funkci TPCI1054U_Error.




//............................................................. TPCI1054U_Version

// Vrac verzi knihovny DLL (nutno vydlit 100, nap. vrcen hodnota 100
// znamen verzi 1.00).
// Parametry funkce:
//  Ver - ukazatel na DWord

function TPCI1054U_Version(Ver:PDWord):DWord; stdcall;




//............................................................. TPCI1054U_Init

// Inicializuje knihovnu, vyhled kartu PCI-1054U a oteve zadan EUART.
// Pole inicializanch parametr (TPar):
// Par[0] - detekce karty PCI-1054U (DWord) - 0=prvni nalezena, 1=podle BUS,SLOT
// Par[1] - BUS (DWord)
// Par[2] - SLOT (DWord)
// Par[3] - EUART (DWord) - 0=EUART1, 1=EUART2, 2=EUART3, 3=EUART4
// Par[4..15] - rezerva
// Nastav default komunikan parametry (9600Bd, timeout 200ms, 2 opakovn
// pi chyb). Vrac handle otevenho zazen.
// Parametry funkce:
//  PHNDL - ukazatel na DWord
//  PPar - ukazatel na pole TPar

function TPCI1054U_Init(PHNDL:PDWord; PPar:PTPar):DWord; stdcall;




//............................................................. TPCI1054U_SetConfig

// Nastav komunikan rychlost, timeout a opakovn pro komunikaci
// s moduly MicroUnit. Povolen rychlosti odpovdaj modulm MicroUnit,
// tj. 600Bd, 1200Bd, 2400Bd, 4800Bd, 9600Bd, 19200Bd, 38400Bd, 57600Bd
// a 115200Bd. Timeout, tj. max. doba ekn na zahjen odpovdi modulu,
// je nastaviteln od 1 do 65535ms. Opakovn uruje poet zopakovanch voln
// na modul MicroUnit v ppad chybn komunikace, tzn. nap. pro Opakovani=2
// je na modul MicroUnit volno v ppad chyby komunikace celkem 3x.
// Pokud vyhov default hodnoty konfigurace (viz. TPCI1054U_Init), nen nutno
// tuto funkci volat.
// Parametry funkce:
//  HNDL - DWord s pidlenm handle zazen
//  Baud,Timeout,Opakovani - DWord s nastavenm komunikanch parametr

function TPCI1054U_SetConfig(HNDL:DWord;Baud,Timeout,Opakovani:DWord):DWord; stdcall;




//............................................................. TPCI1054U_GetConfig

// Vrac nastavenou komunikan rychlost, timeout a opakovn pro komunikaci
// s moduly MicroUnit.
// Parametry funkce:
//  HNDL - DWord s pidlenm handle zazen
//  Baud,Timeout,Opakovani - ukazatel na DWord s nastavenmi komunikanmi parametry

function TPCI1054U_GetConfig(HNDL:DWord; Baud,Timeout,Opakovani:PDWord):DWord; stdcall;




//............................................................. TPCI1054U_Send

// Vyle dotaz (BuffT) na modul MicroUnit, vrt odpov modulu (BuffR),
// Status registr modulu (StatusR) a Status pjmu (StatusP).
// TBuff a RBuff jsou pole obsahujc vyslanou resp. pijatou zprvu.
// Obsah TBuff odpovd vyslan zprv protokolu AIBus-2, bez CRC. Pesn
// vznam je uveden v popisu protokolu.
//  BuffT[0] - adresa volanho modulu MicroUnit (0-255)
//  BuffT[1] - poadovan funkce AIBus-2 (0,1,2,3,100,101,102,103,200)
//  BuffT[2] - poadovan periferie modulu MicroUnit (0-255)
//  BuffT[3] - pm povel (0)
//  BuffT[4] - D1 datov byte dotazu (0-255)
//  BuffT[5] - D2 datov byte dotazu (0-255)
//  BuffT[6] - D3 datov byte dotazu (0-255)
//  BuffT[7] - D4 datov byte dotazu (0-255)
// Pole RBuff obsahuje pouze pijat datov byty odpovdi.
//  BuffR[0] - D1 datov byte odpovdi (0-255)
//  BuffR[1] - D2 datov byte odpovdi (0-255)
//  BuffR[2] - D3 datov byte odpovdi (0-255)
//  BuffR[3] - D4 datov byte odpovdi (0-255)
// StatusR obsahuje pijat Status registr modulu.
// Ve StatusP je uloen kd spnosti komunikace s modulem MicroUnit.
// Slovn popis kdu lze zskat pomoc funkce TPCI1054U_Error.
// Parametry funkce:
//  HNDL - DWord s pidlenm handle zazen
//  BuffT,BuffR - ukazatele na pole
//  StatusR,StatusP - ukazatele na DWord

function TPCI1054U_Send(HNDL:DWord;BuffT,BuffR:PTBuff;StatusR,StatusP:PDWord):DWord; stdcall;




//............................................................. TPCI1054U_Send1

// Vyle dvku dotaz (BuffT) na moduly MicroUnit, vrt odpovdi modul (BuffR).
// BuffT a BuffR jsou pole obsahujc vyslan resp. pijat zprvy azen po osmi
// prvcch za sebou. Maximln je mono pedat 128 zprv.
// Obsah BuffT odpovd vyslan dotazm protokolu AIBus-2, bez CRC. Pesn
// vznam je uveden v popisu protokolu. Jednotliv dotazy jsou azeny za sebou.
//  BuffT[0] - dotaz 1 - adresa volanho modulu MicroUnit (0-255)
//  BuffT[1] - dotaz 1 - poadovan funkce AIBus-2 (0,1,2,3,100,101,102,103,200)
//  BuffT[2] - dotaz 1 - poadovan periferie modulu MicroUnit (0-255)
//  BuffT[3] - dotaz 1 - pm povel (0)
//  BuffT[4] - dotaz 1 - D1 datov byte dotazu (0-255)
//  BuffT[5] - dotaz 1 - D2 datov byte dotazu (0-255)
//  BuffT[6] - dotaz 1 - D3 datov byte dotazu (0-255)
//  BuffT[7] - dotaz 1 - D4 datov byte dotazu (0-255)
//  BuffT[8] - dotaz 2 - adresa volanho modulu MicroUnit (0-255)
//  BuffT[9] - dotaz 2 - poadovan funkce AIBus-2 (0,1,2,3,100,101,102,103,200)
//  BuffT[10] - dotaz 2 - poadovan periferie modulu MicroUnit (0-255)
//  BuffT[11] - dotaz 2 - pm povel (0)
//  BuffT[12] - dotaz 2 - D1 datov byte dotazu (0-255)
//   ...
//  BuffT[1022] - dotaz 128 - D3 datov byte dotazu (0-255)
//  BuffT[1023] - dotaz 128 - D4 datov byte dotazu (0-255)
// Pole BuffR obsahuje pijat datov byty odpovdi (tj. bez hlaviky zprvy),
// status komunikace a Status registr modulu. Odpovdi jsou uloeny po osmi
// prvcch ve stejnm poad jako dotazy.
//  BuffR[0] - odpov 1 - D1 datov byte odpovdi (0-255)
//  BuffR[1] - odpov 1 - D2 datov byte odpovdi (0-255)
//  BuffR[2] - odpov 1 - D3 datov byte odpovdi (0-255)
//  BuffR[3] - odpov 1 - D4 datov byte odpovdi (0-255)
//  BuffR[4] - odpov 1 - Status pjmu (chybov kd komunikace)
//  BuffR[5] - odpov 1 - Status registr modulu
//  BuffR[6] - odpov 1 - rezerva
//  BuffR[7] - odpov 1 - rezerva
//  BuffR[8] - odpov 2 - D1 datov byte odpovdi (0-255)
//  BuffR[9] - odpov 3 - D2 datov byte odpovdi (0-255)
//  BuffR[10] - odpov 4 - D3 datov byte odpovdi (0-255)
//  BuffR[11] - odpov 5 - D4 datov byte odpovdi (0-255)
//  BuffR[12] - odpov 6 - Status pjmu (chybov kd komunikace)
//   ...
//  BuffR[1022] - odpov 128 - rezerva
//  BuffR[1023] - odpov 128 - rezerva
// Slovn popis chybovho kdu lze zskat pomoc funkce TPCI1054U_Error.
// Parametry funkce:
//  HNDL - DWord s pidlenm handle zazen
//  BuffT,BuffR - ukazatele na pole TBuff
//  Count - DWord - poet platnch zprv v BuffT

function TPCI1054U_Send1(HNDL:DWord;BuffT,BuffR:PTBuff;Count:DWord):DWord; stdcall;




//............................................................. TPCI1054U_Done

// Uzavre otevren zarzen a uvoln knihovnu z pameti.
// Parametry funkce:
//  PHNDL - ukazatel na DWord s pridelenm handle zarzen

function TPCI1054U_Done(PHNDL:PDWord):DWord; stdcall;




//............................................................. TPCI1054U_Error

// Prevede nvratov kd na text.
// Parametry funkce:
//  ErrCode - DWord
//  ErrText - ukazatel na pole ErrText

function TPCI1054U_Error(ErrCode:DWord; ErrText:PTBuff):DWord; stdcall;


//________________________________________________________________ IMPLEMENTACE

implementation

//______________________________________________________________________________

function TPCI1054U_Version;                             external 'Tpci1054u.dll';
function TPCI1054U_Init;                                external 'Tpci1054u.dll';
function TPCI1054U_SetConfig;                           external 'Tpci1054u.dll';
function TPCI1054U_GetConfig;                           external 'Tpci1054u.dll';
function TPCI1054U_Send;                                external 'Tpci1054u.dll';
function TPCI1054U_Send1;                               external 'Tpci1054u.dll';
function TPCI1054U_Done;                                external 'Tpci1054u.dll';
function TPCI1054U_Error;                               external 'Tpci1054u.dll';

//______________________________________________________________________________

begin
end.


